import '../../../css/common/index.scss';
import 'datatables.net-bs5/css/dataTables.bootstrap5.css';
import '../../common/index';

import DataTable from 'datatables.net-bs5';
import {Modal} from "bootstrap";

const DT_SERVERSIDE_PROCESSING_URL = '/api/dt/accounts';
const TABLE = document.querySelector('#user-table');

function displayEdit(data: any) {

    const modalElem = document.querySelector('#edit-modal');
    // @ts-ignore
    modalElem.querySelector('.name-input').textContent = data.name;
    // @ts-ignore
    modalElem.querySelector('.login-method').textContent = data.loginMethod;
    // @ts-ignore
    modalElem.querySelector('.permission-editor').value = data.permissionIndex;

    // @ts-ignore
    modalElem?.querySelector('.js--save').dataset.userid = data.userid;

    Modal.getOrCreateInstance('#edit-modal').show();
}

document.addEventListener('DOMContentLoaded', () => {
    const dt = new DataTable('#user-table', {
        ajax: {
            url: DT_SERVERSIDE_PROCESSING_URL,
        },
        serverSide: true,
        columns: [
            {
                data: 'profilePictureUrl',
                render(data, type) {
                    if (type !== 'display') {
                        return data;
                    }

                    return `<img src="${ data }" alt="Profile Picture" class="ratio-1 rounded-circle w-100" />`
                },
                orderable: false,
                searchable: false
            },
            {
                name: 'Name',
                data: 'name'
            },
            {
                name: 'Permission',
                data: 'permission'
            },
            {
                name: 'Login-Method',
                data: 'loginMethod'
            }
        ],
        order: [ [1, 'asc'] ],
        drawCallback: function (settings) {
            const api = new DataTable.Api(settings);
            api.rows().every(function (row) {
                const node = this.node();
                const data = this.data();

                node.addEventListener('click', (e) => {
                    displayEdit(data);
                });
            });
        }
    });

    const button = <HTMLButtonElement>document.querySelector('#edit-modal .js--save');
    if (!button) {
        return;
    }

    button.addEventListener('click', async (e) => {
        const permissionEditor = <HTMLSelectElement>document.querySelector('#edit-modal .permission-editor');
        if (!permissionEditor) {
            return;
        }

        const formData = new FormData();
        formData.set('permission', permissionEditor.value);

        const response = await fetch(
            `/api/web/users/${button.dataset.userid}`,
            {
                method: 'POST',
                body: formData
            }
        );

        if (!response.ok) {
            throw new Error(response.statusText);
        }

        Modal.getOrCreateInstance('#edit-modal').hide();
        dt.draw();
    })
})