import '../../css/common/index.scss';
import '../common/index';

import DataTable, {Api} from "datatables.net-bs5";
import 'datatables.net-bs5/css/dataTables.bootstrap5.css';

const TABLE_AJAX_URL = '/api/dt/keys/available';
const GAME_GET_URL = '/api/web/game';
const CLAIM_URL = '/api/web/key/claim';
function getDetailsHTML(gameData: Game): string
{
    let keyString = '';
    gameData.keys.forEach(key => {
        keyString += `
            <div class="key input-group mb-2" data-key-id="${ key.id }">
                
                <span class="input-group-text flex-grow-1">
                    <i class="${ key.store.icon } me-2"></i>
                    ${ key.store.name }
                    
                    <span class="text-muted ms-2">
                        provided by ${ key.list.owner }
                    </span>
                </span>
                <button class="btn btn-primary claim-btn">Claim</button>
            </div>
        `;
    })
    
    return `
    <div class="row">
        <div class="col-2">
            <div class="ratio border-1 border-light-subtle rounded-3 bg-body-secondary" style="--bs-aspect-ratio: 161.803%">
                <div>Image</div>
            </div>
        </div>
        <div class="col-10">
            <h2>
                ${ gameData.name }
            </h2>
            
            <div class="key-list">
                ${ keyString }
            </div>
            
            <div class="key-claim-display d-none">
                <div class="input-group">
                    <span class="input-group-text store-display">
                        
                    </span>
                    <span class="input-group-text flex-grow-1">
                        <span class="text-center key-display w-100">
                            #####-#####-#####
                        </span>
                    </span>
                    <a class="btn btn-primary open-claim-page-btn" target="_blank" rel="noopener noreferrer">Open Claim Page</a>
                </div>
                <div class="row">
                    <span class="col-6 text-center">
                        <span class="text-muted">provided by:</span> <br>
                        <span class="providedBy"></span>
                    </span>
                    <span class="col-6 text-center">
                        <span class="text-muted">key from: </span><br>
                        <span class="from"></span>
                    </span>
                </div>
            </div>
        </div>
    </div>
    `;
}

async function renderDetails(childRow: HTMLDivElement, gameid: number) {
    const loadingContainer = document.createElement('div');
    loadingContainer.classList.add('m-3', 'mx-auto');
    loadingContainer.style.width = '2rem';
    const spinner = document.createElement('div');
    spinner.classList.add('spinner-border');
    loadingContainer.appendChild(spinner);
    childRow.appendChild(loadingContainer);
    
    const queryParams = new URLSearchParams();
    queryParams.set('gameid', gameid.toString());
    const response = await fetch(
        GAME_GET_URL + '?' + queryParams.toString(),
    )
    
    if (!response.ok) {
        throw new Error(response.statusText);
    }
    
    const gameData: Game = await response.json();
    
    childRow.removeChild(loadingContainer);
    
    const parser = new DOMParser();
    const gameDisplay: HTMLDivElement|null = <HTMLDivElement|null>(parser.parseFromString(getDetailsHTML(gameData), 'text/html').body.firstChild);
    
    if (!gameDisplay) {
        return;
    }
    
    gameDisplay.querySelectorAll('.claim-btn').forEach(btn => {
        btn.addEventListener('click', async () => {
            const key = btn.closest<HTMLDivElement>('.key')?.dataset.keyId ?? 0;
            
            const formData = new FormData();
            formData.set('keyid', key.toString());
            
            const response = await fetch(CLAIM_URL, {
                method: 'POST',
                body: formData
            })
            
            if (!response.ok) {
                throw new Error(response.statusText);
            }
            
            const data = await response.json();
            
            gameDisplay.querySelector('.key-list')?.classList.add('d-none');
            const claimDisplay: HTMLDivElement|null = gameDisplay.querySelector('.key-claim-display')
            
            if (!claimDisplay) {
                throw new Error("Can't find claim display...");
            }
            
            claimDisplay.classList.remove('d-none');
            
            // @ts-expect-error
            claimDisplay.querySelector('.store-display').textContent = data.store.name;
            // @ts-expect-error
            claimDisplay.querySelector('.key-display').textContent = data.key;
            // @ts-expect-error
            claimDisplay.querySelector('.providedBy').textContent = data.providedBy;
            // @ts-expect-error
            claimDisplay.querySelector('.from').textContent = data.from;
            const claimBtn = claimDisplay.querySelector<HTMLAnchorElement>('.open-claim-page-btn');
            if (!claimBtn) {
                return;
            }
            
            if (data.store.claimLink === null) {
                claimBtn.remove();
                return;
            }
            
            claimBtn.href = data.store.claimLink;
        })
    })
    
    childRow.appendChild(gameDisplay);
}

document.addEventListener('DOMContentLoaded', () => {
    const keyTable = document.getElementById('keyTable');
    if (!keyTable) {
        return;
    }
    
    const table = new DataTable(keyTable, {
        ajax: {
            url: TABLE_AJAX_URL,
        },
        columns: [
            {
                data: 'name',
            }
        ],
        createdRow(row: Node, data: any) {
            const tableRow = <HTMLTableRowElement>row;
            tableRow.classList.add('cursor-pointer');

            tableRow.addEventListener('click', () => {
                const rowAPI = table.row(row);
                if (rowAPI.child.isShown()) {
                    rowAPI.child.hide();
                    return;
                }

                const childRow = document.createElement('tr');
                const cell = childRow.insertCell();
                cell.colSpan = row.childNodes.length;
                const cellContainer = document.createElement('div');
                cell.appendChild(cellContainer);
                
                rowAPI.child(childRow).show();
                renderDetails(cellContainer, data.id);
            })
        },
    })
})