import DataTable, {Api} from "datatables.net-bs5";
import 'datatables.net-bs5/css/dataTables.bootstrap5.css';
import {Key} from "../types/entities";
import {getIconForKeyState, getKeyStateExplanation} from "../types/keyState";

import {Dropdown, Tooltip} from "bootstrap";
import {getCurrentlySelectedList} from "./userlists";

const TABLE_AJAX_URL = '/api/dt/keys/provider';

let tableAPI: Api;

export function getTableAPI(): Api {
    return tableAPI;
}

function getKeyDisplay(parent: HTMLElement, keys: Key[]) {
    const header = document.createElement("h1");
    header.innerText = 'Keys';
    header.classList.add('h6');

    const table = document.createElement("table");
    table.classList.add('table', 'table-striped', 'w-100');
    const body = table.createTBody();

    for (const {fromWhere, state, key, store, store_link} of keys) {
        const row = body.insertRow();
        row.classList.add('cursor-pointer');

        const stateCell = row.insertCell();
        stateCell.classList.add('w-auto', 'align-content-center');
        stateCell.innerHTML = `<a data-bs-toggle="tooltip" data-bs-title="${getKeyStateExplanation(state)}"><i class="fa-solid ${ getIconForKeyState(state) }"></i></a>`

        const anchor = stateCell.querySelector('a');
        if (!anchor) {
            return;
        }
        new Tooltip(anchor);

        row.insertCell().textContent = key;
        row.insertCell().textContent = store === 'external' ? store_link : store;
        row.insertCell().textContent = fromWhere;

        row.addEventListener('click', () => {
            console.log('Key options');
        })
    }

    parent.appendChild(header);
    parent.appendChild(table);
}

export function init() {
    const keyTable = document.querySelector<HTMLTableElement>('.key-table');
    if (!keyTable) {
        return;
    }

    const table = tableAPI = new DataTable(keyTable, {
        ajax: {
            url: TABLE_AJAX_URL,
            data: function (d) {
                // @ts-ignore
                d.listid = getCurrentlySelectedList();
            }
        },
        processing: true,
        columns: [
            {
                data: 'gamePicture',
                searchable: false,
                orderable: false
            },
            {
                data: 'name',
            },
            {
                data: 'keysAmount',
                searchable: false,
            },
            {
                data: 'igdbState',
                searchable: false,
            }
        ],
        order: [ [1, 'asc'] ],
        createdRow(row: Node, data: any) {
            const tableRow = <HTMLTableRowElement>row;
            tableRow.classList.add('cursor-pointer');

            tableRow.addEventListener('click', () => {
                const rowAPI = table.row(row);
                if (rowAPI.child.isShown()) {
                    rowAPI.child.hide();
                    return;
                }

                const childRow = document.createElement('tr');
                const cell = childRow.insertCell();
                cell.colSpan = row.childNodes.length;

                getKeyDisplay(cell, data.keys);

                rowAPI.child(childRow).show();
            })
        },
    });
}