<?php
declare(strict_types=1);

namespace GamesShop\Entities\Games;

enum Store: string
{
    case STEAM = 'steam';
    case GOG = 'gog';
    case EPICGAMES = 'epicgames';
    case ORIGIN = 'origin';
    case UPLAY = 'uplay';
    case BATTLENET = 'battlenet';
    case EXTERNAL = 'external';
    
    public function getName(): string 
    {
        return match ($this) {
            self::STEAM => 'Steam',
            self::GOG => "GOG",
            self::EPICGAMES => "Epic Games Store",
            self::ORIGIN => "EA Play / Origin",
            self::UPLAY => "UPlay",
            self::BATTLENET => "Battlenet",
            self::EXTERNAL => "Other",
        };
    }
    
    public function getIcon(): string 
    {
        return match ($this) {
            self::STEAM => 'fa-solid fa-steam',
            default => '',
        };
    }
    
    public function getClaimURL(Key $key): ?string {
        return match ($this) {
            self::STEAM => 'https://store.steampowered.com/account/registerkey?key=' . $key->getKey(),
            self::EXTERNAL => $key->getStoreLink(),
            default => null,
        };
    }
}
