<?php
declare(strict_types=1);

namespace GamesShop\Routing;

use GamesShop\ContainerHandler;
use GamesShop\Login\LoginHandler;
use GamesShop\Login\UserPermission;
use GamesShop\Routing\Responses\TemplateResponse;
use Laminas\Diactoros\Response;
use Laminas\Diactoros\Response\EmptyResponse;
use Laminas\Diactoros\Response\RedirectResponse;
use League\Route\Http\Exception\ForbiddenException;
use League\Route\Http\Exception\UnauthorizedException;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class AdminAccountConfigRoute
{
    public function __construct(
        private readonly LoginHandler $loginHandler
    )
    {
    }

    /**
     * @throws ForbiddenException
     * @throws UnauthorizedException
     */
    public function __invoke(ServerRequestInterface $request): ResponseInterface
    {
        if (!$this->loginHandler->isLoggedIn()) {
            throw new UnauthorizedException();
        }

        $user = $this->loginHandler->getCurrentUser();
        if ($user->getPermission()->value < UserPermission::ADMIN->value) {
            throw new ForbiddenException();
        }


        return new TemplateResponse('admin/accounts');
    }

    public static function applyRoutes(\League\Route\Router $router) {
        $router->get('/accounts', self::class);
    }

}