<?php

namespace GamesShop\Routing\Api\Web;

use Doctrine\ORM\EntityManager;
use GamesShop\Entities\Games\Key;
use GamesShop\Entities\Games\KeyState;
use GamesShop\Entities\GamesList;
use GamesShop\Login\LoginHandler;
use GamesShop\Login\UserPermission;
use Laminas\Diactoros\Response\JsonResponse;
use League\Route\Http\Exception\BadRequestException;
use League\Route\Http\Exception\ForbiddenException;
use League\Route\Http\Exception\UnauthorizedException;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

class ClaimKey
{
    public function __construct(
        private readonly LoginHandler $loginHandler,
        private readonly EntityManager $entityManager,
    )
    {
    }

    public function __invoke(ServerRequestInterface $request): ResponseInterface
    {
        if (!$this->loginHandler->isLoggedIn()) {
            throw new UnauthorizedException();
        }

        $user = $this->loginHandler->getCurrentUser();
        if (!$user->getPermission()->hasLevel(UserPermission::VIEWER)) {
            throw new ForbiddenException();
        }
        
        $body = $request->getParsedBody();
        if (!array_key_exists('keyid', $body)) {
            throw new BadRequestException();
        }
        
        $key = $this->entityManager->getRepository(Key::class)->find($body['keyid']);
        if (!$key instanceof Key) {
            throw new BadRequestException();
        }
        
        if (!$key->getList()->isPublic() && !$key->getList()->getClaimer()->contains($user)) {
            throw new BadRequestException();
        }
        
        if ($key->getState() !== KeyState::AVAILABLE) {
            throw new BadRequestException();
        }
        
        $key->setState(KeyState::CLAIMED);
        $key->setClaimedUser($user);
        $this->entityManager->flush();
        
        return new JsonResponse([
            'key' => $key->getKey(),
            'providedBy' => $key->getList()->getOwner()->getName(),
            'from' => $key->getFromWhere() ?? 'unknown',
            'store' => [
                'name' => $key->getStore()->getName(),
                'icon' => $key->getStore()->getIcon(),
                'claimLink' => $key->getStore()->getClaimURL($key),
            ],
        ]);
    }
}