<?php declare(strict_types=1);

namespace GamesShop\Routing\Api\Web;

use Doctrine\ORM\EntityManager;
use GamesShop\Entities\Games\Key;
use GamesShop\Entities\GamesList;
use GamesShop\Login\LoginHandler;
use GamesShop\Login\UserPermission;
use Laminas\Diactoros\Response;
use League\Route\Http\Exception\BadRequestException;
use League\Route\Http\Exception\ForbiddenException;
use League\Route\Http\Exception\UnauthorizedException;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class DeleteKeyList
{

    public function __construct(
        private readonly LoginHandler $loginHandler,
        private readonly EntityManager $entityManager
    )
    {
    }

    public function __invoke(ServerRequestInterface $request): ResponseInterface
    {
        if (!$this->loginHandler->isLoggedIn()) {
            throw new UnauthorizedException();
        }

        $user = $this->loginHandler->getCurrentUser();
        if (!$user->getPermission()->hasLevel(UserPermission::PROVIDER)) {
            throw new ForbiddenException();
        }

        $body = $request->getParsedBody();
        if (!array_key_exists('id', $body)) {
            throw new BadRequestException();
        }

        $id = $body['id'];
        $list = $this->entityManager->getRepository(GamesList::class)->findOneBy(
            [
                'id' => $id,
                'owner' => $user,
            ]
        );
        
        if ($list === null) {
            throw new BadRequestException();
        }
        
        $this->entityManager->remove($list);

        $keys = $this->entityManager->getRepository(Key::class)->findBy(
            [
                'list' => $list
            ]
        );
        foreach ($keys as $key) {
            $this->entityManager->remove($key);
        }
        
        $this->entityManager->flush();
        
        return new Response();
    }
}