<?php
declare(strict_types=1);

namespace GamesShop\Routing;

use Doctrine\ORM\EntityManager;
use GamesShop\Entities\GamesList;
use GamesShop\Login\LoginHandler;
use GamesShop\Login\UserPermission;
use GamesShop\Routing\Responses\TemplateResponse;
use League\Route\Http\Exception\ForbiddenException;
use League\Route\Http\Exception\UnauthorizedException;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class KeysRoute
{
    public function __construct(
        private readonly LoginHandler $loginHandler,
        private readonly EntityManager $entityManager
    )
    {
    }

    public function __invoke(ServerRequestInterface $request): ResponseInterface
    {
        if (!$this->loginHandler->isLoggedIn()) {
            throw new UnauthorizedException();
        }

        $user = $this->loginHandler->getCurrentUser();
        if (!$user->getPermission()->hasLevel(UserPermission::PROVIDER)) {
            throw new ForbiddenException();
        }

        $entityManager = $this->entityManager->getRepository(GamesList::class);
        $lists = $entityManager->findBy([ 'owner' => $user ]);
        return new TemplateResponse('key-manager', [ 'usersLists' => $lists ]);
    }

    public static function applyRoutes(\League\Route\Router $router): void
    {
        $router->get('/keys', KeysRoute::class);
    }
}