<?php
declare(strict_types=1);

namespace GamesShop\Routing;

use GamesShop\ContainerHandler;
use GamesShop\Login\LoginHandler;
use GamesShop\Routing\Api\APIRoutes;
use GamesShop\Templates\TemplateEngine;
use Laminas\Diactoros\Response;
use Laminas\Diactoros\ServerRequestFactory;
use League\Container\Container;
use League\Route\Http\Exception\BadRequestException;
use League\Route\Http\Exception\ForbiddenException;
use League\Route\Http\Exception\NotFoundException;
use League\Route\Http\Exception\UnauthorizedException;
use League\Route\Strategy\ApplicationStrategy;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;

final class Router
{
    public function route(): ResponseInterface
    {
        $request = ServerRequestFactory::fromGlobals(
            $_SERVER, $_GET, $_POST, $_COOKIE, $_FILES
        );
        
        $router = new \League\Route\Router;
        $strategy = (new ApplicationStrategy)->setContainer(ContainerHandler::getInstance());
        $router->setStrategy($strategy);

        IndexRoute::applyRoutes($router);
        LoginRoutes::addRoutes($router);
        SetupRoute::applyRoutes($router);

        KeysRoute::applyRoutes($router);
        AdminAccountConfigRoute::applyRoutes($router);

        APIRoutes::applyRoutes($router);

        try {
            return $router->dispatch($request);
        } catch (NotFoundException $e) {
            return (new ErrorRoute())->renderErrorPage(404);
        } catch (UnauthorizedException) {
            return (new ErrorRoute())->renderErrorPage(401);
        } catch (ForbiddenException) {
            return (new ErrorRoute())->renderErrorPage(403);
        }
    }
}