<?php
declare(strict_types=1);

namespace GamesShop\Templates;

use GamesShop\Login\LoginHandler;
use GamesShop\Paths;
use League\Plates\Engine;

final class TemplateEngine extends Engine
{
    private const string TEMPLATES_PATH = Paths::SOURCE_PATH . '/templates';

    public function __construct(
        private ResourceIndex $resourceIndex,
        LoginHandler $loginHandler,
    )
    {
        parent::__construct(self::TEMPLATES_PATH, 'php');
        $this->addData([
            'resources' => $this->resourceIndex,
            'activeUser' => $loginHandler->isLoggedIn() ? $loginHandler->getCurrentUser() : null,
        ]);
    }

    public function renderPage(string $page, array $data = array())
    {
        return parent::render("pages/$page", $data);
    }

    public function renderErrorPage(int $error) {
        return self::renderPage('error', [ 'errorCode' => $error ]);
    }
}